@@ -42,7 +42,7 @@ $(function() {
 		var message = {
 			action   : action,
 			params   : params,
-			callback : callback,
+			callback : callback
 		};
 		console.info('sendMessage(' + action + ", ...)");
 		messages.push(message);
@@ -374,7 +374,7 @@ $(function() {
 		CodeMirror.modeURL = "assets/codemirror/mode/%N/%N.js";
 		cm.setOption("mode", mode);
 		CodeMirror.autoLoadMode(cm, modeFile);	
-	}
+	};
 
 	window.showEditorStats = function(cm) {
 
@@ -416,7 +416,7 @@ $(function() {
 	// Returns the current editor filename
 	window.GetCurrentFilename = function() {
 		return editors[currentEditorId].filename;
-	}
+	};
 
 	window.GetOutputEditor = function() {
 		return outputEditor;
@@ -433,7 +433,7 @@ $(function() {
 		var outputEditor = GetOutputEditor();
 		var source = editor.getValue();
 		window.sendMessage('perl-tidy', {"source": source}, function(data) {
-			if(data.error == '') {
+			if(data.error === '') {
 
 				if(source != data.source) {
 
@@ -480,6 +480,10 @@ $(function() {
 						"</thead>";
 					html += "<tbody>";
 
+					var showProblemsTab = function() {
+						$('a[href="#problems-tab"]').tab('show');
+					};
+
 					for(i = 0; i < problems.length; i++) {
 						var problem = problems[i];
 
@@ -499,9 +503,7 @@ $(function() {
 							)
 						);
 
-						$(msg).click(function() {
-							$('a[href="#problems-tab"]').tab('show');
-						});
+						$(msg).click(showProblemsTab);
 
 						html += 
 							"<tr>" +
@@ -521,7 +523,7 @@ $(function() {
 
 				$("#problems > table").html(html);
 				$("#problems>  table > tbody > tr").click(function() { 
-					var line = parseInt($(".problem-line", this).text());
+					var line = parseInt($(".problem-line", this).text(), 10);
 					var editor = GetCurrentEditor();
 					editor.setCursor({line: line - 1, ch: 0});
 				});
@@ -564,8 +566,12 @@ $(function() {
 						"<th>Source</th>" +
 					"</thead>";
 				html += "<tbody>";
-				
-				for (var i = 0; i < JSHINT.errors.length; ++i) {
+
+				var showProblemsTab = function() {
+					$('a[href="#problems-tab"]').tab('show');
+				};
+
+				for (i = 0; i < JSHINT.errors.length; ++i) {
 					var problem = JSHINT.errors[i];
 					if (!problem) {
 						continue;
@@ -587,9 +593,7 @@ $(function() {
 						)
 					);
 
-					$(msg).click(function() {
-						$('a[href="#problems-tab"]').tab('show');
-					});
+					$(msg).click(showProblemsTab);
 
 					html += 
 						"<tr>" +
@@ -609,7 +613,7 @@ $(function() {
 			
 			$("#problems > table").html(html);
 			$("#problems>  table > tbody > tr").click(function() { 
-				var line = parseInt($(".problem-line", this).text());
+				var line = parseInt($(".problem-line", this).text(), 10);
 				var editor = GetCurrentEditor();
 				editor.setCursor({line: line - 1, ch: 0});
 			});
@@ -667,7 +671,7 @@ $(function() {
 		}
 	}).change(function() {
 		_displayHelp($(this).val(), true);
-	});;
+	});
 	
 	$(document).on('action-new-file', function() {
 		AddEditorTab();
@@ -685,11 +689,11 @@ $(function() {
 
 		// Utility function to find if the object is empty or not
 		var isEmpty = function (obj) {
-		    for (var key in obj) {
-			    return false;
-		    }
-		    return true;
-		}
+			for (var key in obj) {
+				return false;
+			}
+			return true;
+		};
 		
 		// Remove the current tab from the UI
 		var currentTabId = editors[currentEditorId].tabId;
@@ -731,7 +735,7 @@ $(function() {
 		var editor = GetCurrentEditor();
 		var filename = GetCurrentFilename();
 		window.sendMessage('save-file', {"filename": filename, "source": editor.getValue()}, function(data) {
-			if(data.err == '') {
+			if(data.err === '') {
 				editor.markClean();
 				showStarAfterNameIfModified(editor);
 			} else {
@@ -750,13 +754,13 @@ $(function() {
 		// Get the editor selection and fallback to
 		// all editor contents
 		var source = editor.getSelection();
-		if(source == '') {
+		if(source === '') {
 			source = editor.getValue();
 		}
 
 		sendMessage('dump-ppi-tree', {"source": source}, function(data) {
 
-			if(data.error == '') {
+			if(data.error === '') {
 				outputEditor.setValue(data.output);
 			} else {
 				outputEditor.setValue(data.error);
