@@ -17,19 +17,31 @@ $(function() {
 			for(var i = 0; i < results.length; i++) {
 				var result = results[i];
 				html += "<option id='" + result.id + "' "  + 
-					((i == 0) ? "selected" : "") + 
+					((i === 0) ? "selected" : "") + 
 					">" + 
 					result.name + 
 					"</option>";
 			}
-			
+
 			// OK button is disabled for now
 			$("#ok-button", $dialog).removeAttr("disabled");
-			
+
 			// Add matched files HTML
 			$("#matched-files", $dialog).html(html);
+
+			// On each selection change in the matched files list, display the corresponding path
+			$("#matched-files", $dialog).change(function() {
+				var html = [];
+				$("#matched-files :selected", $dialog).each(function(key, value) {
+					html.push($(value).attr("id"));
+				});
+				$("#path", $dialog).html(html.join("<br>"));
+			});
+
+			$("#matched-files :selected", $dialog).change();
+
 		});
-	}
+	};
 
 	// Called the open files action is triggered
 	$(document).on('action-open-file', function() {
@@ -97,7 +109,7 @@ $(function() {
 		$("#matched-files option:selected", $dialog).each(function(key, value) { 
 			var filename = $(value).attr("id");
 
-			if (filename.length == 0) {
+			if (filename.length === 0) {
 				console.warn("file name is empty");
 				return;
 			}
